@@ -39,67 +39,72 @@ from .log import FAIL, LOG
 class IntegrationStatus:
     running: bool
     start_time: datetime
-    error_message: 'Optional[str]'
-    error_time: 'Optional[datetime]'
+    error_message: "Optional[str]"
+    error_time: "Optional[datetime]"
     pending_events: int
-    event_queue: 'IntegrationQueueStatus'
-    webhooks: 'Sequence[WebhookRouteStatus]'
-    ledger_events: 'Sequence[LedgerHandlerStatus]'
-    timers: 'Sequence[InvocationStatus]'
-    queues: 'Sequence[InvocationStatus]'
+    event_queue: "IntegrationQueueStatus"
+    webhooks: "Sequence[WebhookRouteStatus]"
+    ledger_events: "Sequence[LedgerHandlerStatus]"
+    timers: "Sequence[InvocationStatus]"
+    queues: "Sequence[InvocationStatus]"
 
 
 def normalize_metadata_field(field_value, field_type_info):
-    LOG.debug('Normalizing %r with field_type_info: %r',
-              field_value, field_type_info)
+    LOG.debug("Normalizing %r with field_type_info: %r", field_value, field_type_info)
 
     return field_value.strip()
 
 
 def normalize_metadata(metadata, integration_type):
-    LOG.debug('Normalizing metadata %r for integration type: %r',
-              metadata, integration_type)
+    LOG.debug(
+        "Normalizing metadata %r for integration type: %r", metadata, integration_type
+    )
 
     field_types = {field.id: field for field in integration_type.fields}
 
-    return {field_id: normalize_metadata_field(field_value, field_types.get(field_id))
-            for (field_id, field_value)
-            in metadata.items()}
+    return {
+        field_id: normalize_metadata_field(field_value, field_types.get(field_id))
+        for (field_id, field_value) in metadata.items()
+    }
 
 
 def _as_int(value: Any) -> int:
     return int(value)
 
+
 def parse_qualified_symbol(symbol_text: str):
 
     try:
-        (module_name, sym_name) = symbol_text.split(':')
+        (module_name, sym_name) = symbol_text.split(":")
     except ValueError:
-        FAIL(f'Malformed symbol {symbol_text} (Must be [module_name:symbol_name])')
+        FAIL(f"Malformed symbol {symbol_text} (Must be [module_name:symbol_name])")
 
     module = None
 
     try:
-        LOG.debug(f'Searching for module {module_name} in qualified symbol {symbol_text}')
+        LOG.debug(
+            f"Searching for module {module_name} in qualified symbol {symbol_text}"
+        )
         module = import_module(module_name)
     except:  # noqa
-        FAIL(f'Failure importing integration package: {module_name}')
+        FAIL(f"Failure importing integration package: {module_name}")
 
     if module is None:
-        FAIL(f'Unknown module {module_name} in {symbol_text}')
+        FAIL(f"Unknown module {module_name} in {symbol_text}")
 
     return (module, sym_name)
 
 
 class IntegrationContext:
-
-    def __init__(self,
-                 network: 'Network',
-                 config: 'Configuration',
-                 integration_type: 'IntegrationTypeInfo',
-                 type_id: str,
-                 integration_spec: 'IntegrationRuntimeSpec',
-                 metadata: 'PackageMetadata'):
+    def __init__(
+        self,
+        network: "Network",
+        config: "Configuration",
+        integration_type: "IntegrationTypeInfo",
+        type_id: str,
+        integration_spec: "IntegrationRuntimeSpec",
+        metadata: "PackageMetadata",
+    ):
 
         self.start_time = datetime.utcnow()
 
@@ -112,7 +117,7 @@ class IntegrationContext:
 
         self._party_fallback_to_metadata()
 
-        LOG.info(f'Running as party: {self.run_as_party}')
+        LOG.info(f"Running as party: {self.run_as_party}")
 
         self.running = False
         self.error_message = None  # type: Optional[str]
@@ -139,37 +144,38 @@ class IntegrationContext:
 
         metadata = self.integration_spec.metadata
 
-        self.run_as_party = \
-            metadata.get(METADATA_COMMON_RUN_AS_PARTY) \
-            or metadata.get(METADATA_INTEGRATION_RUN_AS_PARTY)
+        self.run_as_party = metadata.get(METADATA_COMMON_RUN_AS_PARTY) or metadata.get(
+            METADATA_INTEGRATION_RUN_AS_PARTY
+        )
 
         if self.run_as_party is None:
-            FAIL('DAML_LEDGER_PARTY environment variable undefined.')
+            FAIL("DAML_LEDGER_PARTY environment variable undefined.")
 
     def get_integration_entrypoint(
-            self,
-            integration_type: 'IntegrationTypeInfo') -> 'IntegrationEntryPoint':
+        self, integration_type: "IntegrationTypeInfo"
+    ) -> "IntegrationEntryPoint":
 
         (module, entry_fn_name) = parse_qualified_symbol(integration_type.entrypoint)
 
         return getattr(module, entry_fn_name)
 
     def get_integration_env_class(
-            self,
-            integration_type: 'IntegrationTypeInfo') -> 'Type[IntegrationEnvironment]':
+        self, integration_type: "IntegrationTypeInfo"
+    ) -> "Type[IntegrationEnvironment]":
 
         if integration_type.env_class:
-            (module, env_class_name) = parse_qualified_symbol(integration_type.env_class)
+            (module, env_class_name) = parse_qualified_symbol(
+                integration_type.env_class
+            )
 
             return getattr(module, env_class_name)
         else:
             return IntegrationEnvironment
 
-
     async def _load(self):
         metadata = self.integration_spec.metadata
 
-        LOG.info('Starting ledger client for party: %r', self.run_as_party)
+        LOG.info("Starting ledger client for party: %r", self.run_as_party)
 
         client = self.network.aio_party(self.run_as_party)
         self.client = client
@@ -183,29 +189,29 @@ class IntegrationContext:
 
         self.queue_context = IntegrationQueueContext(self.queue, client)
         self.time_context = IntegrationTimeContext(self.queue, client)
-        self.ledger_context = IntegrationLedgerContext(self.queue, client, self.metadata.daml_model)
+        self.ledger_context = IntegrationLedgerContext(
+            self.queue, client, self.metadata.daml_model
+        )
         self.webhook_context = IntegrationWebhookContext(self.queue, client)
 
         events = IntegrationEvents(
             queue=self.queue_context,
             time=self.time_context,
             ledger=self.ledger_context,
-            webhook=self.webhook_context)
+            webhook=self.webhook_context,
+        )
 
         integration_env_data = {
             **metadata,
-            'queue': self.queue_context.sink,
-            'party': self.run_as_party,
-            'daml_model': self.metadata.daml_model
-            }
+            "queue": self.queue_context.sink,
+            "party": self.run_as_party,
+            "daml_model": self.metadata.daml_model,
+        }
 
         integration_env = from_dict(
             data_class=env_class,
             data=integration_env_data,
-            config=Config(type_hooks={
-                bool: to_boolean,
-                int: _as_int
-            })
+            config=Config(type_hooks={bool: to_boolean, int: _as_int}),
         )
 
         user_coro = entry_fn(integration_env, events)
@@ -220,20 +226,18 @@ class IntegrationContext:
 
         self.int_toplevel_coro = asyncio.gather(*int_coros)
 
-
     async def _start(self):
-        LOG.info('Starting integration...')
+        LOG.info("Starting integration...")
 
         await self.client.ready()
-        LOG.info('...Ledger client ready, processing sweeps...')
+        LOG.info("...Ledger client ready, processing sweeps...")
 
         await self.ledger_context.process_sweeps()
 
         self.running = True
-        LOG.info('...sweeps procesed, integration started.')
+        LOG.info("...sweeps procesed, integration started.")
 
-
-    def get_status(self) -> 'IntegrationStatus':
+    def get_status(self) -> "IntegrationStatus":
         queue_status = self.queue.get_status()
 
         return IntegrationStatus(
@@ -244,9 +248,12 @@ class IntegrationContext:
             pending_events=queue_status.pending_events,
             event_queue=queue_status,
             webhooks=self.webhook_context.get_status() if self.webhook_context else [],
-            ledger_events=self.ledger_context.get_status() if self.ledger_context else [],
+            ledger_events=self.ledger_context.get_status()
+            if self.ledger_context
+            else [],
             timers=self.time_context.get_status() if self.time_context else [],
-            queues=self.queue_context.get_status() if self.queue_context else [])
+            queues=self.queue_context.get_status() if self.queue_context else [],
+        )
 
     async def safe_load(self):
         try:
@@ -254,7 +261,7 @@ class IntegrationContext:
         except:  # noqa
             ex = sys.exc_info()[1]
 
-            self.error_message = f'{repr(ex)} - {str(ex)}'
+            self.error_message = f"{repr(ex)} - {str(ex)}"
             self.error_time = datetime.utcnow()
 
             LOG.exception("Failure loading integration.")
@@ -265,7 +272,7 @@ class IntegrationContext:
         except:  # noqa
             ex = sys.exc_info()[1]
 
-            self.error_message = f'{repr(ex)} - {str(ex)}'
+            self.error_message = f"{repr(ex)} - {str(ex)}"
             self.error_time = datetime.utcnow()
 
             LOG.exception("Failure starting integration.")
