@@ -30,26 +30,26 @@ from .package_metadata_introspection import get_package_metadata
 from .web import start_web_endpoint
 
 
-def load_integration_spec(config: 'Configuration') -> 'Optional[IntegrationRuntimeSpec]':
+def load_integration_spec(
+    config: "Configuration",
+) -> "Optional[IntegrationRuntimeSpec]":
     spec_path = Path(config.integration_spec_path)
 
     if spec_path.exists():
-        LOG.debug('Loading integration spec from: %r', spec_path)
+        LOG.debug("Loading integration spec from: %r", spec_path)
 
-        yaml_spec=yaml.safe_load(spec_path.read_bytes())
+        yaml_spec = yaml.safe_load(spec_path.read_bytes())
 
-        LOG.info('Integration spec: %r', yaml_spec)
+        LOG.info("Integration spec: %r", yaml_spec)
 
-        return from_dict(
-            data_class=IntegrationRuntimeSpec,
-            data=yaml_spec)
+        return from_dict(data_class=IntegrationRuntimeSpec, data=yaml_spec)
 
     else:
-        LOG.error(f'No spec file found at: {repr(spec_path)}')
+        LOG.error(f"No spec file found at: {repr(spec_path)}")
         return None
 
 
-def create_network(url: str) -> 'Network':
+def create_network(url: str) -> "Network":
     token = optenv("DAML_LEDGER_TOKEN")
     app_name = optenv("DAML_LEDGER_APPLICATION_NAME")
     network = Network()
@@ -57,59 +57,63 @@ def create_network(url: str) -> 'Network':
     return network
 
 
-async def run_dazl_network(network: 'Network'):
+async def run_dazl_network(network: "Network"):
     """
     Run the dazl network, and make sure that fatal dazl errors terminate the application.
     """
     try:
-        LOG.info('Starting dazl network...')
+        LOG.info("Starting dazl network...")
 
         await network.aio_run()
     except:  # noqa
-        LOG.exception('The main dazl coroutine died with an exception')
+        LOG.exception("The main dazl coroutine died with an exception")
 
-    FAIL('Execution cannot continue without dazl coroutine.')
+    FAIL("Execution cannot continue without dazl coroutine.")
 
 
 async def _aio_main(
-        integration_type: 'IntegrationTypeInfo',
-        config: 'Configuration',
-        type_id: str,
-        integration_spec: 'IntegrationRuntimeSpec',
-        metadata: 'PackageMetadata'):
+    integration_type: "IntegrationTypeInfo",
+    config: "Configuration",
+    type_id: str,
+    integration_spec: "IntegrationRuntimeSpec",
+    metadata: "PackageMetadata",
+):
 
     network = create_network(config.ledger_url)
     dazl_coro = ensure_future(run_dazl_network(network))
 
-    integration_context = \
-        IntegrationContext(
-            network, config, integration_type, type_id, integration_spec, metadata)
+    integration_context = IntegrationContext(
+        network, config, integration_type, type_id, integration_spec, metadata
+    )
 
     await integration_context.safe_load()
 
     integration_coro = integration_context.get_coro()
 
     if integration_coro:
-        LOG.info('Integration coroutine ready, starting web endpoint.')
+        LOG.info("Integration coroutine ready, starting web endpoint.")
 
         web_coro = start_web_endpoint(config, integration_context)
 
         integration_startup_coro = integration_context.safe_start()
 
-        LOG.info('Starting main loop.')
-        await gather(
-            web_coro, dazl_coro, integration_coro, integration_startup_coro)
+        LOG.info("Starting main loop.")
+        await gather(web_coro, dazl_coro, integration_coro, integration_startup_coro)
 
         return True
 
     return False
 
 
-def _get_integration_types(metadata: 'PackageMetadata') -> 'Dict[str, IntegrationTypeInfo]':
+def _get_integration_types(
+    metadata: "PackageMetadata",
+) -> "Dict[str, IntegrationTypeInfo]":
 
-    package_itypes = (metadata.integration_types
-                      or metadata.integrations  # support for deprecated
-                      or [])
+    package_itypes = (
+        metadata.integration_types
+        or metadata.integrations  # support for deprecated
+        or []
+    )
 
     return {itype.id: itype for itype in package_itypes}
 
@@ -117,7 +121,7 @@ def _get_integration_types(metadata: 'PackageMetadata') -> 'Dict[str, Integratio
 def main():
     setup_default_logging()
 
-    LOG.info('Initializing dabl-integration...')
+    LOG.info("Initializing dabl-integration...")
 
     # Parsing certain DAML-LF modules causes very deep stacks;
     # increase the standard limit to be able to handle those.
@@ -144,21 +148,22 @@ def main():
         # Guide the user to provide the type ID via the current
         # environment variable rather than with the deprecated config
         # file approach.
-        raise Exception('DABL_INTEGRATION_TYPE_ID environment variable undefined')
+        raise Exception("DABL_INTEGRATION_TYPE_ID environment variable undefined")
 
     integration_type = integration_types.get(type_id)
 
     if not integration_type:
-        FAIL(f'No integration of type {type_id}')
+        FAIL(f"No integration of type {type_id}")
 
     if integration_spec:
-        LOG.info('Running integration type: %r...', type_id)
+        LOG.info("Running integration type: %r...", type_id)
 
         loop = get_event_loop()
 
         if not loop.run_until_complete(
-                _aio_main(integration_type, config, type_id, integration_spec, metadata)):
-            FAIL('Error initializing integration, shutting down.')
+            _aio_main(integration_type, config, type_id, integration_spec, metadata)
+        ):
+            FAIL("Error initializing integration, shutting down.")
 
     else:
-        FAIL('No metadata file. Terminating without running')
+        FAIL("No metadata file. Terminating without running")
